@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use HTML::TokeParser;
 use Encode qw(decode_utf8 encode_utf8);
-use Glib qw(TRUE FALSE);    # To get TRUE and FALSE
+use Glib   qw(TRUE FALSE);                # To get TRUE and FALSE
 use Gscan2pdf::Document;
 use Carp;
 use JSON::PP;
@@ -23,7 +23,7 @@ BEGIN {
     use Exporter ();
     our ( $VERSION, @EXPORT_OK, %EXPORT_TAGS );
 
-    $VERSION = '2.13.4';
+    $VERSION = '2.13.5';
 
     use base qw(Exporter);
     %EXPORT_TAGS = ();    # eg: TAG => [ qw!name1 name2! ],
@@ -193,7 +193,7 @@ sub _hocr2boxes {
             }
             if ( defined $data ) {
                 if ( $tag eq 'strong' ) { push @{ $data->{style} }, 'Bold' }
-                if ( $tag eq 'em' ) { push @{ $data->{style} }, 'Italic' }
+                if ( $tag eq 'em' )     { push @{ $data->{style} }, 'Italic' }
             }
 
             # put the new data point on the stack
@@ -205,7 +205,7 @@ sub _hocr2boxes {
                 chomp $data->{text};
             }
         }
-        elsif ( $token->[0] eq 'E') {
+        elsif ( $token->[0] eq 'E' ) {
 
             # up a level
             $data = pop @stack;
@@ -649,8 +649,7 @@ sub _crop_axis {
     if ( $text1 > $crop2 or $text2 < $crop1 ) { return }
 
     # crop inside edges of box
-    if ( $text1 <= $crop1 and $text2 >= $crop2 )
-    {    ## no critic (ProhibitCascadingIfElse)
+    if ( $text1 <= $crop1 and $text2 >= $crop2 ) {    ## no critic (ProhibitCascadingIfElse)
         $text1 = 0;
         $text2 = $crop2 - $crop1;
     }
