@@ -28,7 +28,7 @@ BEGIN {
     Readonly $MAX_CONFIDENCE_DEFAULT => 95;
     Readonly $MIN_CONFIDENCE_DEFAULT => 50;
 }
-our $VERSION = '2.13.4';
+our $VERSION = '2.13.5';
 
 use Glib::Object::Subclass GooCanvas2::Canvas::, signals => {
     'zoom-changed' => {
@@ -104,8 +104,7 @@ sub INIT_INSTANCE {
     $self->signal_connect( 'motion-notify-event'  => \&_motion );
     $self->signal_connect( 'scroll-event'         => \&_scroll );
     if (
-        $Glib::Object::Introspection::VERSION <
-        0.043    ## no critic (ProhibitMagicNumbers)
+        $Glib::Object::Introspection::VERSION < 0.043    ## no critic (ProhibitMagicNumbers)
       )
     {
         $self->add_events(
@@ -257,8 +256,8 @@ sub string2hsv {
 
 sub string2rgb {
     my ($spec) = @_;
-    my $color = Gtk3::Gdk::Color::parse($spec)->to_string;
-    my @color = unpack 'xA4A4A4', $color;
+    my $color  = Gtk3::Gdk::Color::parse($spec)->to_string;
+    my @color  = unpack 'xA4A4A4', $color;
     for (@color) { $_ = hex }
     return @color;
 }
