@@ -294,7 +294,7 @@ use Glib::Object::Subclass Gscan2pdf::Dialog::, signals => {
     ),
   ];
 
-our $VERSION = '2.13.3';
+our $VERSION = '2.13.5';
 
 my ( $d_sane, $logger );
 my $SANE_NAME_SCAN_TL_X   = SANE_NAME_SCAN_TL_X;
@@ -911,12 +911,12 @@ sub SET_PROPERTY {
         elsif ( $name eq 'device' ) {
             $self->{$name} = $newval;
             $self->set_device($newval);
-            $self->signal_emit( 'changed-device', $newval )
+            $self->signal_emit( 'changed-device', $newval );
         }
         elsif ( $name eq 'device_list' ) {
             $self->{$name} = $newval;
             $self->set_device_list($newval);
-            $self->signal_emit( 'changed-device-list', $newval )
+            $self->signal_emit( 'changed-device-list', $newval );
         }
         elsif ( $name eq 'document' ) {
             $self->{$name} = $newval;
@@ -937,11 +937,11 @@ sub SET_PROPERTY {
         }
         elsif ( $name eq 'page_number_start' ) {
             $self->{$name} = $newval;
-            $self->signal_emit( 'changed-page-number-start', $newval )
+            $self->signal_emit( 'changed-page-number-start', $newval );
         }
         elsif ( $name eq 'page_number_increment' ) {
             $self->{$name} = $newval;
-            $self->signal_emit( 'changed-page-number-increment', $newval )
+            $self->signal_emit( 'changed-page-number-increment', $newval );
         }
         elsif ( $name eq 'side_to_scan' ) {
             $self->_set_side_to_scan( $name, $newval );
@@ -963,8 +963,7 @@ sub SET_PROPERTY {
                 for ( @{ $self->{ignored_paper_formats} } ) {
                     if ( $_ eq $newval ) {
                         if ( defined $logger ) {
-                            $logger->info(
-                                "Ignoring unsupported paper $newval");
+                            $logger->info("Ignoring unsupported paper $newval");
                             $logger->debug("Finished$msg");
                         }
                         return;
@@ -976,11 +975,9 @@ sub SET_PROPERTY {
             $signal = $self->signal_connect(
                 'changed-paper' => sub {
                     $self->signal_handler_disconnect($signal);
-                    my $paper = defined $newval ? $newval : __('Manual');
-                    my $retval =
-                      $self->{combobp}->set_active_by_text($paper);
-                    $logger->debug(
-                        "Widget update to $paper returned $retval");
+                    my $paper  = defined $newval ? $newval : __('Manual');
+                    my $retval = $self->{combobp}->set_active_by_text($paper);
+                    $logger->debug("Widget update to $paper returned $retval");
                     if ( defined $logger ) {
                         $logger->debug("Finished$msg");
                     }
@@ -991,7 +988,7 @@ sub SET_PROPERTY {
         elsif ( $name eq 'paper_formats' ) {
             $self->{$name} = $newval;
             $self->set_paper_formats($newval);
-            $self->signal_emit( 'changed-paper-formats', $newval )
+            $self->signal_emit( 'changed-paper-formats', $newval );
         }
         elsif ( $name eq 'profile' ) {
             $callback = TRUE;
@@ -1236,22 +1233,22 @@ sub pack_widget {
         if ( $opt->{unit} != SANE_UNIT_NONE ) {
             my $text;
             if ( $opt->{unit} == SANE_UNIT_PIXEL ) {
-                $text = __('pel')
+                $text = __('pel');
             }
             elsif ( $opt->{unit} == SANE_UNIT_BIT ) {
-                $text = __('bit')
+                $text = __('bit');
             }
             elsif ( $opt->{unit} == SANE_UNIT_MM ) {
-                $text = __('mm')
+                $text = __('mm');
             }
             elsif ( $opt->{unit} == SANE_UNIT_DPI ) {
-                $text = __('ppi')
+                $text = __('ppi');
             }
             elsif ( $opt->{unit} == SANE_UNIT_PERCENT ) {
-                $text = __(q{%})
+                $text = __(q{%});
             }
             elsif ( $opt->{unit} == SANE_UNIT_MICROSECOND ) {
-                $text = __('μs')
+                $text = __('μs');
             }
             my $label = Gtk3::Label->new($text);
             $hbox->pack_end( $label, FALSE, FALSE, 0 );
@@ -1331,7 +1328,8 @@ sub create_paper_widget {
                 }
                 elsif ( $self->{combobp}->get_active_text eq __('Manual') ) {
                     for (
-                        ( SANE_NAME_SCAN_TL_X, SANE_NAME_SCAN_TL_Y,
+                        (
+                            SANE_NAME_SCAN_TL_X,   SANE_NAME_SCAN_TL_Y,
                             SANE_NAME_SCAN_BR_X,   SANE_NAME_SCAN_BR_Y,
                             SANE_NAME_PAGE_HEIGHT, SANE_NAME_PAGE_WIDTH
                         )
@@ -1353,7 +1351,8 @@ sub create_paper_widget {
         # If the geometry is changed, unset the paper size,
         # if we are not setting a profile
         for (
-            ( SANE_NAME_SCAN_TL_X, SANE_NAME_SCAN_TL_Y,
+            (
+                SANE_NAME_SCAN_TL_X,   SANE_NAME_SCAN_TL_Y,
                 SANE_NAME_SCAN_BR_X,   SANE_NAME_SCAN_BR_Y,
                 SANE_NAME_PAGE_HEIGHT, SANE_NAME_PAGE_WIDTH
             )
@@ -1379,7 +1378,8 @@ sub create_paper_widget {
 sub hide_geometry {
     my ( $self, $options ) = @_;
     for (
-        ( SANE_NAME_SCAN_TL_X, SANE_NAME_SCAN_TL_Y,
+        (
+            SANE_NAME_SCAN_TL_X,   SANE_NAME_SCAN_TL_Y,
             SANE_NAME_SCAN_BR_X,   SANE_NAME_SCAN_BR_Y,
             SANE_NAME_PAGE_HEIGHT, SANE_NAME_PAGE_WIDTH
         )
@@ -1551,8 +1551,8 @@ sub _update_option {
             }
 
             # ComboBox
-            elsif ( $opt->{constraint_type} == SANE_CONSTRAINT_STRING_LIST or
-                $opt->{constraint_type} == SANE_CONSTRAINT_WORD_LIST )
+            elsif ($opt->{constraint_type} == SANE_CONSTRAINT_STRING_LIST
+                or $opt->{constraint_type} == SANE_CONSTRAINT_WORD_LIST )
             {
                 $widget->get_model->clear;
                 my $index = 0;
@@ -1642,28 +1642,34 @@ sub set_paper {
         and not $options->by_name(SANE_NAME_PAGE_WIDTH)->{cap} &
         SANE_CAP_INACTIVE )
     {
-        $paper_profile->add_backend_option( SANE_NAME_PAGE_HEIGHT,
+        $paper_profile->add_backend_option(
+            SANE_NAME_PAGE_HEIGHT,
             $formats->{$paper}{y} + $formats->{$paper}{t},
             $options->by_name(SANE_NAME_PAGE_HEIGHT)->{val}
         );
-        $paper_profile->add_backend_option( SANE_NAME_PAGE_WIDTH,
+        $paper_profile->add_backend_option(
+            SANE_NAME_PAGE_WIDTH,
             $formats->{$paper}{x} + $formats->{$paper}{l},
             $options->by_name(SANE_NAME_PAGE_WIDTH)->{val}
         );
     }
-    $paper_profile->add_backend_option( SANE_NAME_SCAN_TL_X,
+    $paper_profile->add_backend_option(
+        SANE_NAME_SCAN_TL_X,
         $formats->{$paper}{l},
         $options->by_name(SANE_NAME_SCAN_TL_X)->{val}
     );
-    $paper_profile->add_backend_option( SANE_NAME_SCAN_TL_Y,
+    $paper_profile->add_backend_option(
+        SANE_NAME_SCAN_TL_Y,
         $formats->{$paper}{t},
         $options->by_name(SANE_NAME_SCAN_TL_Y)->{val}
     );
-    $paper_profile->add_backend_option( SANE_NAME_SCAN_BR_X,
+    $paper_profile->add_backend_option(
+        SANE_NAME_SCAN_BR_X,
         $formats->{$paper}{x} + $formats->{$paper}{l},
         $options->by_name(SANE_NAME_SCAN_BR_X)->{val}
     );
-    $paper_profile->add_backend_option( SANE_NAME_SCAN_BR_Y,
+    $paper_profile->add_backend_option(
+        SANE_NAME_SCAN_BR_Y,
         $formats->{$paper}{y} + $formats->{$paper}{t},
         $options->by_name(SANE_NAME_SCAN_BR_Y)->{val}
     );
@@ -2182,7 +2188,7 @@ sub add_value {
             my ( $widget, $target, $event ) = @_;
             if (
                 not(
-                    $event->state >=  ## no critic (ProhibitMismatchedOperators)
+                    $event->state >=    ## no critic (ProhibitMismatchedOperators)
                     'button1-mask'
                 )
               )
@@ -2477,10 +2483,8 @@ sub update_widget_value {
         $logger->debug( "Setting widget '$opt->{name}'"
               . ( $opt->{type} == SANE_TYPE_BUTTON ? $EMPTY : " to '$val'." ) );
         $widget->signal_handler_block( $widget->{signal} );
-        if (
-                 $widget->isa('Gtk3::CheckButton')
-              or $widget->isa('Gtk3::Switch')
-          )
+        if (   $widget->isa('Gtk3::CheckButton')
+            or $widget->isa('Gtk3::Switch') )
         {
             if ( $val eq $EMPTY ) { $val = 0 }
             if ( $widget->get_active != $val ) {
