@@ -39,7 +39,7 @@ use Glib::Object::Subclass Gscan2pdf::Dialog::Scan::, properties => [
     ),
 ];
 
-our $VERSION = '2.13.3';
+our $VERSION = '2.13.5';
 
 my $SANE_NAME_SCAN_TL_X   = SANE_NAME_SCAN_TL_X;
 my $SANE_NAME_SCAN_TL_Y   = SANE_NAME_SCAN_TL_Y;
@@ -263,8 +263,7 @@ sub _initialise_options {    ## no critic (ProhibitExcessComplexity)
             }
 
             # Switch
-            if ( $opt->{type} == SANE_TYPE_BOOL )
-            {    ## no critic (ProhibitCascadingIfElse)
+            if ( $opt->{type} == SANE_TYPE_BOOL ) {    ## no critic (ProhibitCascadingIfElse)
                 $widget = Gtk3::Switch->new;
                 if ($val) { $widget->set_active(TRUE) }
                 $widget->{signal} = $widget->signal_connect(
@@ -290,7 +289,7 @@ sub _initialise_options {    ## no critic (ProhibitExcessComplexity)
             # SpinButton
             elsif ( $opt->{constraint_type} == SANE_CONSTRAINT_RANGE ) {
                 my $step = 1;
-                if ( $opt->{constraint}{quant} ) {
+                if ( $opt->{constraint}{quant} and $opt->{constraint}{quant} > 0 ) {
                     $step = $opt->{constraint}{quant};
                 }
                 if ( $opt->{constraint}{min} > $opt->{constraint}{max} ) {
@@ -368,7 +367,7 @@ sub _initialise_options {    ## no critic (ProhibitExcessComplexity)
                 );
             }
         }
-        else {                                       # $opt->{max_values} > 1
+        else {    # $opt->{max_values} > 1
             $widget = Gtk3::Button->new( $d_sane->get( $opt->{title} ) );
             $widget->{signal} = $widget->signal_connect(
                 clicked =>
