@@ -6,7 +6,7 @@ use warnings;
 use Locale::gettext 1.05;    # For translations
 use Carp;
 use Text::ParseWords;
-use Glib qw(TRUE FALSE);
+use Glib  qw(TRUE FALSE);
 use POSIX qw(locale_h :signal_h :errno_h :sys_wait_h);
 use Proc::Killfam;
 use IPC::Open3;
@@ -25,7 +25,7 @@ Readonly my $_1KB                         => 1024;
 Readonly my $ALL_PENDING_ZOMBIE_PROCESSES => -1;
 Readonly my $INFINITE_DOCUMENTS           => -1;
 
-our $VERSION = '2.13.4';
+our $VERSION = '2.13.5';
 
 my $EMPTY = q{};
 my $COMMA = q{,};
@@ -185,7 +185,8 @@ sub parse_scanimage_output {
               ->( 0, sprintf __('Scanning page %i...'), $1 );
         }
     }
-    elsif ( $line =~ /^Scanned[ ]$page_no [.][ ][(]scanner[ ]status[ ]=[ ](\d)[)]/xsm)
+    elsif ( $line =~
+        /^Scanned[ ]$page_no [.][ ][(]scanner[ ]status[ ]=[ ](\d)[)]/xsm )
     {
         my ( $id, $return ) = ( $1, $2 );
         if ( $return == SANE_STATUS_EOF ) {
@@ -208,12 +209,13 @@ sub parse_scanimage_output {
             );
         }
     }
-    elsif ( $line =~ $mess_warmingup) {
+    elsif ( $line =~ $mess_warmingup ) {
         if ( defined $options->{running_callback} ) {
             $options->{running_callback}->( 0, __('Scanner warming up') );
         }
     }
-    elsif ( $line =~
+    elsif (
+        $line =~
 /^$options->{frontend}:[ ]sane_start:[ ]Document[ ]feeder[ ]out[ ]of[ ]documents/xsm ## no critic (ProhibitComplexRegexes)
       )
     {
@@ -226,7 +228,7 @@ sub parse_scanimage_output {
     }
     elsif (
         $_self->{abort_scan} == TRUE
-          and ( $line =~
+        and ( $line =~
 qr{^$options->{frontend}:[ ]sane_start:[ ]Error[ ]during[ ]device[ ]I/O}xsm
             or $line =~ /^$options->{frontend}:[ ]received[ ]signal/xsm
             or $line =~ /^$options->{frontend}:[ ]aborting/xsm
@@ -242,7 +244,8 @@ qr{^$options->{frontend}:[ ]sane_start:[ ]Error[ ]during[ ]device[ ]I/O}xsm
     elsif ( $line =~ /^Batch[ ]terminated,[ ]\d+[ ]pages?[ ]scanned/xsm ) {
         $logger->info( substr $line, 0, index( $line, "\n" ) + 1 );
     }
-    elsif ( $line =~ /^$options->{frontend}:[ ]sane_(?:start|read):[ ]Device[ ]busy/xsm )
+    elsif ( $line =~
+        /^$options->{frontend}:[ ]sane_(?:start|read):[ ]Device[ ]busy/xsm )
     {
         if ( defined $options->{error_callback} ) {
             $options->{error_callback}->( __('Device busy') );
@@ -258,10 +261,9 @@ qr{^$options->{frontend}:[ ]sane_start:[ ]Error[ ]during[ ]device[ ]I/O}xsm
     }
     else {
         if ( defined $options->{error_callback} ) {
-            $options->{error_callback}->(
-                __('Unknown message: ') . substr $line,
-                0, index $line, "\n"
-            );
+            $options->{error_callback}
+              ->( __('Unknown message: ') . substr $line, 0, index $line,
+                "\n" );
         }
     }
     return;
@@ -395,8 +397,7 @@ sub _scanadf {
 
                     # 50 is enough of the file for the header to be complete
                     elsif ( -e "out$id.pnm"
-                        and ( -s "out$id.pnm" ) >
-                        50 )    ## no critic (ProhibitMagicNumbers)
+                        and ( -s "out$id.pnm" ) > 50 )    ## no critic (ProhibitMagicNumbers)
                     {
                         ($size) = Gscan2pdf::NetPBM::file_size_from_header(
                             "out$id.pnm");
@@ -420,8 +421,7 @@ sub _scanadf {
             my ($line) = @_;
             if ( $line =~ $mess_warmingup ) {
                 if ( defined $options{running_callback} ) {
-                    $options{running_callback}
-                      ->( 0, __('Scanner warming up') );
+                    $options{running_callback}->( 0, __('Scanner warming up') );
                 }
             }
             elsif ( $line =~ /^Scanned[ ]document[ ]out(\d*)[.]pnm/xsm ) {
@@ -433,8 +433,7 @@ sub _scanadf {
                     sub {
                         my $path =
                           defined( $options{dir} )
-                          ? File::Spec->catfile( $options{dir},
-                            "out$id.pnm" )
+                          ? File::Spec->catfile( $options{dir}, "out$id.pnm" )
                           : "out$id.pnm";
                         if ( not -e $path ) {
                             return Glib::SOURCE_CONTINUE;
@@ -446,8 +445,8 @@ sub _scanadf {
                     }
                 );
 
-   # Prevent the Glib::Timeout from checking the size of the file when it is
-   # about to be renamed
+       # Prevent the Glib::Timeout from checking the size of the file when it is
+       # about to be renamed
                 undef $size;
 
             }
@@ -457,7 +456,9 @@ sub _scanadf {
             elsif ( $line =~ /^$options{frontend}:[ ]rounded/xsm ) {
                 $logger->info( substr $line, 0, index( $line, "\n" ) + 1 );
             }
-            elsif ( $line =~ /^$options{frontend}:[ ]sane_start:[ ]Device[ ]busy/xsm ) {
+            elsif ( $line =~
+                /^$options{frontend}:[ ]sane_start:[ ]Device[ ]busy/xsm )
+            {
                 if ( defined $options{error_callback} ) {
                     $options{error_callback}->( __('Device busy') );
                 }
@@ -536,7 +537,7 @@ sub _watch_cmd {
     # Interface to scanimage
     my ( $write, $read );
     my $error = IO::Handle->new;    # this needed because of a bug in open3.
-    my $pid = IPC::Open3::open3( $write, $read, $error, $options{cmd} );
+    my $pid   = IPC::Open3::open3( $write, $read, $error, $options{cmd} );
     $logger->info("Forked PID $pid");
 
     # change back to original directory
