@@ -4,7 +4,7 @@ use 5.008005;
 use strict;
 use warnings;
 use Carp;
-use Glib qw(TRUE FALSE);             # To get TRUE and FALSE
+use Glib qw(TRUE FALSE);    # To get TRUE and FALSE
 use File::Copy;
 use File::Temp;                      # To create temporary files
 use Image::Magick;
@@ -29,7 +29,7 @@ BEGIN {
     use Exporter ();
     our ( $VERSION, @EXPORT_OK, %EXPORT_TAGS );
 
-    $VERSION = '2.13.4';
+    $VERSION = '2.13.5';
 
     use base qw(Exporter);
     %EXPORT_TAGS = ();    # eg: TAG => [ qw!name1 name2! ],
@@ -316,7 +316,9 @@ sub get_resolution {
     # B&W are Portable anymap
     my $image  = $self->im_object;
     my $format = $image->Get('format');
-    if ( $format !~ /^Portable[ ]...map/xsm ) {
+    if (    $format !~ /^Portable[ ]...map/xsm
+        and $image->Get('x-resolution') != 1 )
+    {
         $self->{xresolution} = $image->Get('x-resolution');
         $self->{yresolution} = $image->Get('y-resolution');
 
