@@ -16,10 +16,10 @@ BEGIN {
     use Exporter ();
     our ( $VERSION, @EXPORT_OK, %EXPORT_TAGS );
 
-    $VERSION = '2.13.4';
+    $VERSION = '2.13.5';
 
     use base qw(Exporter);
-    %EXPORT_TAGS = ();              # eg: TAG => [ qw!name1 name2! ],
+    %EXPORT_TAGS = ();    # eg: TAG => [ qw!name1 name2! ],
 
     # your exported package globals go here,
     # as well as any optionally exported functions
@@ -72,7 +72,7 @@ sub new {
             string  => __('Writing system'),
             options => {
                 ltr => {
-                    string => __('Left-to-right'),
+                    string  => __('Left-to-right'),
                     tooltip =>
                       __('Most writings systems, e.g. Latin, Greek, Cyrillic.'),
                 },
@@ -133,8 +133,8 @@ sub new {
             default => FALSE,
         },
         'no-border-align' => {
-            type   => 'CheckButton',
-            string => __('No border align'),
+            type    => 'CheckButton',
+            string  => __('No border align'),
             tooltip =>
               __('Disable aligning of the area detected by border scanning.'),
             default => FALSE,
@@ -147,8 +147,8 @@ sub new {
             ),
             options => {
                 left => {
-                    type   => 'CheckButton',
-                    string => __('Left'),
+                    type    => 'CheckButton',
+                    string  => __('Left'),
                     tooltip =>
                       __("Use 'left' for scanning from the left edge."),
                 },
@@ -158,8 +158,8 @@ sub new {
                     tooltip => __("Use 'top' for scanning from the top edge."),
                 },
                 right => {
-                    type   => 'CheckButton',
-                    string => __('Right'),
+                    type    => 'CheckButton',
+                    string  => __('Right'),
                     tooltip =>
                       __("Use 'right' for scanning from the right edge."),
                 },
@@ -227,13 +227,13 @@ sub new {
             },
         },
         'white-threshold' => {
-            type   => 'SpinButton',
-            string => __('White threshold'),
+            type    => 'SpinButton',
+            string  => __('White threshold'),
             tooltip =>
               __('Brightness ratio above which a pixel is considered white.'),
             min     => 0,
             max     => 1,
-            step    => .01,
+            step    => 0.01,
             default => 0.9,
         },
         'black-threshold' => {
@@ -244,7 +244,7 @@ sub new {
             ),
             min     => 0,
             max     => 1,
-            step    => .01,
+            step    => 0.01,
             default => 0.33,
         },
     };
@@ -439,8 +439,7 @@ sub add_widget {
         my @tooltip;
         my $i = 0;
         for ( keys %{ $hashref->{$option}{options} } ) {
-            $widget->append_text(
-                $hashref->{$option}{options}{$_}{string} );
+            $widget->append_text( $hashref->{$option}{options}{$_}{string} );
             push @tooltip, $hashref->{$option}{options}{$_}{tooltip};
             $hashref->{$option}{options}{$_}{index} = $i++;
         }
@@ -535,8 +534,7 @@ sub get_option {
         elsif ( $hashref->{$option}{type} eq 'CheckButtonGroup' ) {
             my @items;
             for ( sort keys %{ $hashref->{$option}{options} } ) {
-                if ( $hashref->{$option}{options}{$_}{widget}->get_active )
-                {
+                if ( $hashref->{$option}{options}{$_}{widget}->get_active ) {
                     push @items, $_;
                 }
             }
@@ -577,15 +575,14 @@ sub set_options {
     for my $option ( keys %{$options} ) {
         if ( defined $hashref->{$option}{widget} ) {
             if ( $hashref->{$option}{type} eq 'ComboBox' ) {
-                my $i = $hashref->{$option}{options}{ $options->{$option} }
-                  {index};
+                my $i =
+                  $hashref->{$option}{options}{ $options->{$option} }{index};
                 if ( defined $i ) {
                     $hashref->{$option}{widget}->set_active($i);
                 }
             }
             elsif ( $hashref->{$option}{type} eq 'CheckButton' ) {
-                $hashref->{$option}{widget}
-                  ->set_active( $options->{$option} );
+                $hashref->{$option}{widget}->set_active( $options->{$option} );
             }
             elsif ( $hashref->{$option}{type} eq 'CheckButtonGroup' ) {
                 my %default;
@@ -600,8 +597,7 @@ sub set_options {
                 }
             }
             elsif ( $hashref->{$option}{type} eq 'SpinButton' ) {
-                $hashref->{$option}{widget}
-                  ->set_value( $options->{$option} );
+                $hashref->{$option}{widget}->set_value( $options->{$option} );
             }
             elsif ( $hashref->{$option}{type} eq 'SpinButtonGroup' ) {
                 my @default;
